@@ -1,4 +1,4 @@
-/* $Id: bibtexconv.cc 1346 2012-02-13 15:16:23Z dreibh $
+/* $Id: bibtexconv.cc 1352 2012-03-19 10:12:12Z dreibh $
  *
  * BibTeX Converter
  * Copyright (C) 2010-2012 by Thomas Dreibholz
@@ -535,7 +535,7 @@ int main(int argc, char** argv)
    bool        interactive              = true;
    bool        checkURLs                = false;
    bool        checkNewURLsOnly         = false;
-   bool        skipNotesWithISBNandISSN = true;
+   bool        skipNotesWithISBNandISSN = false;
    bool        addNotesWithISBNandISSN  = false;
    bool        addUrlCommand            = false;
    const char* exportToBibTeX           = NULL;
@@ -624,6 +624,48 @@ int main(int argc, char** argv)
          if(checkURLs) {
             result += checkAllURLs(&publicationSet, downloadDirectory, checkNewURLsOnly);
          }
+
+         // ====== Export all to BibTeX =====================================
+         if(exportToBibTeX) {
+            if(PublicationSet::exportPublicationSetToBibTeX(
+               &publicationSet, exportToBibTeX, false,
+               skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+               exit(1);
+            }
+         }
+         if(exportToSeparateBibTeXs) {
+            if(PublicationSet::exportPublicationSetToBibTeX(
+               &publicationSet, exportToSeparateBibTeXs, true,
+               skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
+               exit(1);
+            }
+         }
+
+         // ====== Export all to XML ========================================
+         if(exportToXML) {
+            if(PublicationSet::exportPublicationSetToXML(
+               &publicationSet, exportToXML, false) == false) {
+               exit(1);
+            }
+         }
+         if(exportToSeparateXMLs) {
+            if(PublicationSet::exportPublicationSetToXML(
+               &publicationSet, exportToSeparateXMLs, true) == false) {
+               exit(1);
+            }
+         }
+
+         // ====== Export all to custom format ==============================
+         if(exportToCustom) {
+            if(PublicationSet::exportPublicationSetToCustom(
+                  &publicationSet, "%u",
+                  customPrintingHeader, customPrintingTrailer,
+                  customPrintingTemplate, monthNames,
+                  nbsp, useXMLStyle, downloadDirectory,
+                  stdout) == false) {
+               exit(1);
+            }
+         }
       }
       else {
          fprintf(stderr, "Got %u publications from BibTeX file.\n",
@@ -632,53 +674,10 @@ int main(int argc, char** argv)
                               downloadDirectory, checkURLs, checkNewURLsOnly,
                               exportToBibTeX, exportToSeparateBibTeXs,
                               exportToXML, exportToSeparateXMLs,
-                              addUrlCommand,
-                              skipNotesWithISBNandISSN, addNotesWithISBNandISSN);
+                              skipNotesWithISBNandISSN, addNotesWithISBNandISSN,
+                              addUrlCommand);
          fprintf(stderr, "Done. %u errors have occurred.\n", result);
       }
-
-
-      // ====== Export all to BibTeX ========================================
-      if(exportToBibTeX) {
-         if(PublicationSet::exportPublicationSetToBibTeX(
-            &publicationSet, exportToBibTeX, false,
-            skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
-            exit(1);
-         }
-      }
-      if(exportToSeparateBibTeXs) {
-         if(PublicationSet::exportPublicationSetToBibTeX(
-            &publicationSet, exportToSeparateBibTeXs, true,
-            skipNotesWithISBNandISSN, addNotesWithISBNandISSN, addUrlCommand) == false) {
-            exit(1);
-         }
-      }
-
-      // ====== Export all to XML ===========================================
-      if(exportToXML) {
-         if(PublicationSet::exportPublicationSetToXML(
-            &publicationSet, exportToXML, false) == false) {
-            exit(1);
-         }
-      }
-      if(exportToSeparateXMLs) {
-         if(PublicationSet::exportPublicationSetToXML(
-            &publicationSet, exportToSeparateXMLs, true) == false) {
-            exit(1);
-         }
-      }
-
-      // ====== Export all to custom format =================================
-      if(exportToCustom) {
-         if(PublicationSet::exportPublicationSetToCustom(
-               &publicationSet, "%u",
-               customPrintingHeader, customPrintingTrailer,
-               customPrintingTemplate, monthNames,
-               nbsp, useXMLStyle, downloadDirectory,
-               stdout) == false) {
-            exit(1);
-         }
-      }
    }
    if(bibTeXFile) {
       freeNode(bibTeXFile);
